"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import openapi_client
from openapi_client.model.header_element import HeaderElement
globals()['HeaderElement'] = HeaderElement
from openapi_client.model.header import Header


class TestHeader(unittest.TestCase):
    """Header unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testHeader(self):
        """Test Header"""
        # FIXME: construct object with mandatory attributes with example values
        # model = Header()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
