"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.tenant_migration_api import TenantMigrationApi  # noqa: E501


class TestTenantMigrationApi(unittest.TestCase):
    """TenantMigrationApi unit test stubs"""

    def setUp(self):
        self.api = TenantMigrationApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_download_tenant_data(self):
        """Test case for download_tenant_data

        """
        pass

    def test_export_tenant_data(self):
        """Test case for export_tenant_data

        """
        pass

    def test_get_migration_token(self):
        """Test case for get_migration_token

        """
        pass

    def test_import_tenant_data(self):
        """Test case for import_tenant_data

        """
        pass

    def test_migrate_network(self):
        """Test case for migrate_network

        """
        pass

    def test_re_trigger_network_migration(self):
        """Test case for re_trigger_network_migration

        """
        pass


if __name__ == '__main__':
    unittest.main()
