"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.monitoring_security_unified_logging_connection_events_api import MonitoringSecurityUnifiedLoggingConnectionEventsApi  # noqa: E501


class TestMonitoringSecurityUnifiedLoggingConnectionEventsApi(unittest.TestCase):
    """MonitoringSecurityUnifiedLoggingConnectionEventsApi unit test stubs"""

    def setUp(self):
        self.api = MonitoringSecurityUnifiedLoggingConnectionEventsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_aggregation_data_by_query14(self):
        """Test case for get_aggregation_data_by_query14

        """
        pass

    def test_get_count16(self):
        """Test case for get_count16

        """
        pass

    def test_get_count_post16(self):
        """Test case for get_count_post16

        """
        pass

    def test_get_filter_policy_name_list(self):
        """Test case for get_filter_policy_name_list

        """
        pass

    def test_get_post_aggregation_app_data_by_query13(self):
        """Test case for get_post_aggregation_app_data_by_query13

        """
        pass

    def test_get_post_aggregation_data_by_query13(self):
        """Test case for get_post_aggregation_data_by_query13

        """
        pass

    def test_get_post_stat_bulk_raw_data14(self):
        """Test case for get_post_stat_bulk_raw_data14

        """
        pass

    def test_get_stat_bulk_raw_data14(self):
        """Test case for get_stat_bulk_raw_data14

        """
        pass

    def test_get_stat_data_fields16(self):
        """Test case for get_stat_data_fields16

        """
        pass

    def test_get_stat_data_raw_data_as_csv14(self):
        """Test case for get_stat_data_raw_data_as_csv14

        """
        pass

    def test_get_stat_query_fields16(self):
        """Test case for get_stat_query_fields16

        """
        pass

    def test_get_stats_raw_data14(self):
        """Test case for get_stats_raw_data14

        """
        pass

    def test_get_sul_stat_data_raw_data(self):
        """Test case for get_sul_stat_data_raw_data

        """
        pass


if __name__ == '__main__':
    unittest.main()
