"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.monitoring_colocation_cluster_api import MonitoringColocationClusterApi  # noqa: E501


class TestMonitoringColocationClusterApi(unittest.TestCase):
    """MonitoringColocationClusterApi unit test stubs"""

    def setUp(self):
        self.api = MonitoringColocationClusterApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_cluster_config_by_cluster_id(self):
        """Test case for get_cluster_config_by_cluster_id

        """
        pass

    def test_get_cluster_details_by_cluster_id(self):
        """Test case for get_cluster_details_by_cluster_id

        """
        pass

    def test_get_cluster_port_mapping_by_cluster_id(self):
        """Test case for get_cluster_port_mapping_by_cluster_id

        """
        pass

    def test_get_device_detail_by_device_id(self):
        """Test case for get_device_detail_by_device_id

        """
        pass

    def test_get_pnf_config(self):
        """Test case for get_pnf_config

        """
        pass

    def test_get_service_chain_details(self):
        """Test case for get_service_chain_details

        """
        pass

    def test_get_service_group_by_cluster_id(self):
        """Test case for get_service_group_by_cluster_id

        """
        pass

    def test_get_system_status_by_device_id(self):
        """Test case for get_system_status_by_device_id

        """
        pass

    def test_get_vnf_alarm_count(self):
        """Test case for get_vnf_alarm_count

        """
        pass

    def test_get_vnf_events_count_detail(self):
        """Test case for get_vnf_events_count_detail

        """
        pass

    def test_get_vnf_events_detail(self):
        """Test case for get_vnf_events_detail

        """
        pass

    def test_get_vnf_interface_detail(self):
        """Test case for get_vnf_interface_detail

        """
        pass

    def test_getpnf_details(self):
        """Test case for getpnf_details

        """
        pass

    def test_getvnf_by_device_id(self):
        """Test case for getvnf_by_device_id

        """
        pass

    def test_getvnf_details(self):
        """Test case for getvnf_details

        """
        pass

    def test_list_network_function_map(self):
        """Test case for list_network_function_map

        """
        pass

    def test_vnf_actions(self):
        """Test case for vnf_actions

        """
        pass


if __name__ == '__main__':
    unittest.main()
