"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.real_time_monitoring_utd_api import RealTimeMonitoringUTDApi  # noqa: E501


class TestRealTimeMonitoringUTDApi(unittest.TestCase):
    """RealTimeMonitoringUTDApi unit test stubs"""

    def setUp(self):
        self.api = RealTimeMonitoringUTDApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_signature_version_info(self):
        """Test case for get_signature_version_info

        """
        pass

    def test_get_utd_dataplane_config(self):
        """Test case for get_utd_dataplane_config

        """
        pass

    def test_get_utd_dataplane_global(self):
        """Test case for get_utd_dataplane_global

        """
        pass

    def test_get_utd_dataplane_stats(self):
        """Test case for get_utd_dataplane_stats

        """
        pass

    def test_get_utd_dataplane_stats_summary(self):
        """Test case for get_utd_dataplane_stats_summary

        """
        pass

    def test_get_utd_engine_instance_status(self):
        """Test case for get_utd_engine_instance_status

        """
        pass

    def test_get_utd_engine_status(self):
        """Test case for get_utd_engine_status

        """
        pass

    def test_get_utd_file_analysis_status(self):
        """Test case for get_utd_file_analysis_status

        """
        pass

    def test_get_utd_file_reputation_status(self):
        """Test case for get_utd_file_reputation_status

        """
        pass

    def test_get_utd_ips_update_status(self):
        """Test case for get_utd_ips_update_status

        """
        pass

    def test_get_utd_urlf_connection_status(self):
        """Test case for get_utd_urlf_connection_status

        """
        pass

    def test_get_utd_urlf_update_status(self):
        """Test case for get_utd_urlf_update_status

        """
        pass

    def test_get_utd_version_status(self):
        """Test case for get_utd_version_status

        """
        pass


if __name__ == '__main__':
    unittest.main()
