"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.scheduled_backup_restore_api import ScheduledBackupRestoreApi  # noqa: E501


class TestScheduledBackupRestoreApi(unittest.TestCase):
    """ScheduledBackupRestoreApi unit test stubs"""

    def setUp(self):
        self.api = ScheduledBackupRestoreApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_schduled_backup(self):
        """Test case for delete_schduled_backup

        """
        pass

    def test_delete_schedule(self):
        """Test case for delete_schedule

        """
        pass

    def test_download_backup_file(self):
        """Test case for download_backup_file

        """
        pass

    def test_export_backup(self):
        """Test case for export_backup

        """
        pass

    def test_get_local_backup_info(self):
        """Test case for get_local_backup_info

        """
        pass

    def test_get_schedule_record_for_backup(self):
        """Test case for get_schedule_record_for_backup

        """
        pass

    def test_import_scheduled_backup(self):
        """Test case for import_scheduled_backup

        """
        pass

    def test_list_backup(self):
        """Test case for list_backup

        """
        pass

    def test_list_schedules(self):
        """Test case for list_schedules

        """
        pass

    def test_remote_import_backup(self):
        """Test case for remote_import_backup

        """
        pass

    def test_schedule_backup(self):
        """Test case for schedule_backup

        """
        pass


if __name__ == '__main__':
    unittest.main()
