"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.utility_logging_api import UtilityLoggingApi  # noqa: E501


class TestUtilityLoggingApi(unittest.TestCase):
    """UtilityLoggingApi unit test stubs"""

    def setUp(self):
        self.api = UtilityLoggingApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_debug_log(self):
        """Test case for debug_log

        """
        pass

    def test_list_log_file_details(self):
        """Test case for list_log_file_details

        """
        pass

    def test_list_loggers(self):
        """Test case for list_loggers

        """
        pass

    def test_list_v_manage_server_log_last_n_lines(self):
        """Test case for list_v_manage_server_log_last_n_lines

        """
        pass

    def test_set_log_level(self):
        """Test case for set_log_level

        """
        pass


if __name__ == '__main__':
    unittest.main()
