"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.real_time_monitoring_orchestrator_api import RealTimeMonitoringOrchestratorApi  # noqa: E501


class TestRealTimeMonitoringOrchestratorApi(unittest.TestCase):
    """RealTimeMonitoringOrchestratorApi unit test stubs"""

    def setUp(self):
        self.api = RealTimeMonitoringOrchestratorApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_connection_history_list(self):
        """Test case for create_connection_history_list

        """
        pass

    def test_create_connection_list_from_device(self):
        """Test case for create_connection_list_from_device

        """
        pass

    def test_create_connection_summary(self):
        """Test case for create_connection_summary

        """
        pass

    def test_create_local_properties_list_list(self):
        """Test case for create_local_properties_list_list

        """
        pass

    def test_create_reverse_proxy_mapping_list(self):
        """Test case for create_reverse_proxy_mapping_list

        """
        pass

    def test_create_valid_devices_list(self):
        """Test case for create_valid_devices_list

        """
        pass

    def test_create_valid_v_smarts_list(self):
        """Test case for create_valid_v_smarts_list

        """
        pass

    def test_get_statistics(self):
        """Test case for get_statistics

        """
        pass

    def test_get_valid_v_manage_id(self):
        """Test case for get_valid_v_manage_id

        """
        pass


if __name__ == '__main__':
    unittest.main()
