"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.configuration_settings_api import ConfigurationSettingsApi  # noqa: E501


class TestConfigurationSettingsApi(unittest.TestCase):
    """ConfigurationSettingsApi unit test stubs"""

    def setUp(self):
        self.api = ConfigurationSettingsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_analytics_data_file(self):
        """Test case for create_analytics_data_file

        """
        pass

    def test_edit_cert_configuration(self):
        """Test case for edit_cert_configuration

        """
        pass

    def test_edit_configuration(self):
        """Test case for edit_configuration

        """
        pass

    def test_get_banner(self):
        """Test case for get_banner

        """
        pass

    def test_get_cert_configuration(self):
        """Test case for get_cert_configuration

        """
        pass

    def test_get_configuration_by_setting_type(self):
        """Test case for get_configuration_by_setting_type

        """
        pass

    def test_get_google_map_key(self):
        """Test case for get_google_map_key

        """
        pass

    def test_get_maintenance_window(self):
        """Test case for get_maintenance_window

        """
        pass

    def test_get_session_timout(self):
        """Test case for get_session_timout

        """
        pass

    def test_new_cert_configuration(self):
        """Test case for new_cert_configuration

        """
        pass

    def test_new_configuration(self):
        """Test case for new_configuration

        """
        pass


if __name__ == '__main__':
    unittest.main()
