"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.configuration_cloud_express_api import ConfigurationCloudExpressApi  # noqa: E501


class TestConfigurationCloudExpressApi(unittest.TestCase):
    """ConfigurationCloudExpressApi unit test stubs"""

    def setUp(self):
        self.api = ConfigurationCloudExpressApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_apps(self):
        """Test case for add_apps

        """
        pass

    def test_add_cloudx_interfaces(self):
        """Test case for add_cloudx_interfaces

        """
        pass

    def test_add_cloudx_type(self):
        """Test case for add_cloudx_type

        """
        pass

    def test_delete_webex_prefix_lists(self):
        """Test case for delete_webex_prefix_lists

        """
        pass

    def test_edit_apps(self):
        """Test case for edit_apps

        """
        pass

    def test_enable_webex(self):
        """Test case for enable_webex

        """
        pass

    def test_enable_webex1(self):
        """Test case for enable_webex1

        """
        pass

    def test_get_apps(self):
        """Test case for get_apps

        """
        pass

    def test_get_attached_client_list(self):
        """Test case for get_attached_client_list

        """
        pass

    def test_get_attached_dia_list(self):
        """Test case for get_attached_dia_list

        """
        pass

    def test_get_attached_gateway_list(self):
        """Test case for get_attached_gateway_list

        """
        pass

    def test_get_cloud_x_available_apps(self):
        """Test case for get_cloud_x_available_apps

        """
        pass

    def test_get_cloud_x_status(self):
        """Test case for get_cloud_x_status

        """
        pass

    def test_get_dia_list(self):
        """Test case for get_dia_list

        """
        pass

    def test_get_gateway_list(self):
        """Test case for get_gateway_list

        """
        pass

    def test_get_site_list(self):
        """Test case for get_site_list

        """
        pass

    def test_site_per_app(self):
        """Test case for site_per_app

        """
        pass


if __name__ == '__main__':
    unittest.main()
