"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.colocation_service_chain_api import ColocationServiceChainApi  # noqa: E501


class TestColocationServiceChainApi(unittest.TestCase):
    """ColocationServiceChainApi unit test stubs"""

    def setUp(self):
        self.api = ColocationServiceChainApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_attach_service_chain(self):
        """Test case for attach_service_chain

        """
        pass

    def test_attach_service_chain1(self):
        """Test case for attach_service_chain1

        """
        pass

    def test_cancel_button(self):
        """Test case for cancel_button

        """
        pass

    def test_detach_service_chain(self):
        """Test case for detach_service_chain

        """
        pass

    def test_get_edge_devices(self):
        """Test case for get_edge_devices

        """
        pass

    def test_getpnf_devices(self):
        """Test case for getpnf_devices

        """
        pass


if __name__ == '__main__':
    unittest.main()
