
# flake8: noqa

# Import all APIs into this package.
# If you have many APIs here with many many models used in each API this may
# raise a `RecursionError`.
# In order to avoid this, import only the API that you directly need like:
#
#   from openapi_client.api.administration_audit_log_api import AdministrationAuditLogApi
#
# or import this package, but before doing it, use:
#
#   import sys
#   sys.setrecursionlimit(n)

# Import APIs into API package:
from openapi_client.api.administration_audit_log_api import AdministrationAuditLogApi
from openapi_client.api.administration_user_and_group_api import AdministrationUserAndGroupApi
from openapi_client.api.certificate_management_device_api import CertificateManagementDeviceApi
from openapi_client.api.certificate_management_v_manage_api import CertificateManagementVManageApi
from openapi_client.api.cluster_management_api import ClusterManagementApi
from openapi_client.api.colocation_cluster_api import ColocationClusterApi
from openapi_client.api.colocation_service_chain_api import ColocationServiceChainApi
from openapi_client.api.colocation_service_group_api import ColocationServiceGroupApi
from openapi_client.api.configuration_advanced_inspection_profile_definition_api import ConfigurationAdvancedInspectionProfileDefinitionApi
from openapi_client.api.configuration_azure_connect_api import ConfigurationAzureConnectApi
from openapi_client.api.configuration_circuits_api import ConfigurationCircuitsApi
from openapi_client.api.configuration_cloud_express_api import ConfigurationCloudExpressApi
from openapi_client.api.configuration_cloud_on_ramp_api import ConfigurationCloudOnRampApi
from openapi_client.api.configuration_configuration_group_api import ConfigurationConfigurationGroupApi
from openapi_client.api.configuration_dashboard_status_api import ConfigurationDashboardStatusApi
from openapi_client.api.configuration_device_actions_api import ConfigurationDeviceActionsApi
from openapi_client.api.configuration_device_config_history_api import ConfigurationDeviceConfigHistoryApi
from openapi_client.api.configuration_device_firmware_update_api import ConfigurationDeviceFirmwareUpdateApi
from openapi_client.api.configuration_device_inventory_api import ConfigurationDeviceInventoryApi
from openapi_client.api.configuration_device_ssl_proxy_certificate_management_api import ConfigurationDeviceSSLProxyCertificateManagementApi
from openapi_client.api.configuration_device_software_package_api import ConfigurationDeviceSoftwarePackageApi
from openapi_client.api.configuration_device_software_update_api import ConfigurationDeviceSoftwareUpdateApi
from openapi_client.api.configuration_device_template_api import ConfigurationDeviceTemplateApi
from openapi_client.api.configuration_disaster_recovery_api import ConfigurationDisasterRecoveryApi
from openapi_client.api.configuration_fqdn_list_builder_api import ConfigurationFQDNListBuilderApi
from openapi_client.api.configuration_feature_certificate_api import ConfigurationFeatureCertificateApi
from openapi_client.api.configuration_feature_profile_mobility_api import ConfigurationFeatureProfileMobilityApi
from openapi_client.api.configuration_feature_profile_sdwan_api import ConfigurationFeatureProfileSDWANApi
from openapi_client.api.configuration_general_template_api import ConfigurationGeneralTemplateApi
from openapi_client.api.configuration_multi_cloud_api import ConfigurationMultiCloudApi
from openapi_client.api.configuration_multidomain_policy_api import ConfigurationMultidomainPolicyApi
from openapi_client.api.configuration_network_design_api import ConfigurationNetworkDesignApi
from openapi_client.api.configuration_network_design_templates_api import ConfigurationNetworkDesignTemplatesApi
from openapi_client.api.configuration_policy_amp_definition_builder_api import ConfigurationPolicyAMPDefinitionBuilderApi
from openapi_client.api.configuration_policy_as_path_list_builder_api import ConfigurationPolicyASPathListBuilderApi
from openapi_client.api.configuration_policy_access_list_definition_builder_api import ConfigurationPolicyAccessListDefinitionBuilderApi
from openapi_client.api.configuration_policy_app_route_definition_builder_api import ConfigurationPolicyAppRouteDefinitionBuilderApi
from openapi_client.api.configuration_policy_app_probe_class_builder_api import ConfigurationPolicyAppProbeClassBuilderApi
from openapi_client.api.configuration_policy_application_list_builder_api import ConfigurationPolicyApplicationListBuilderApi
from openapi_client.api.configuration_policy_cflowd_definition_builder_api import ConfigurationPolicyCflowdDefinitionBuilderApi
from openapi_client.api.configuration_policy_cloud_application_builder_api import ConfigurationPolicyCloudApplicationBuilderApi
from openapi_client.api.configuration_policy_color_list_builder_api import ConfigurationPolicyColorListBuilderApi
from openapi_client.api.configuration_policy_community_list_builder_api import ConfigurationPolicyCommunityListBuilderApi
from openapi_client.api.configuration_policy_control_definition_builder_api import ConfigurationPolicyControlDefinitionBuilderApi
from openapi_client.api.configuration_policy_custom_application_builder_api import ConfigurationPolicyCustomApplicationBuilderApi
from openapi_client.api.configuration_policy_data_definition_builder_api import ConfigurationPolicyDataDefinitionBuilderApi
from openapi_client.api.configuration_policy_data_ipv6_prefix_list_builder_api import ConfigurationPolicyDataIPV6PrefixListBuilderApi
from openapi_client.api.configuration_policy_data_prefix_all_types_of_lists_builder_api import ConfigurationPolicyDataPrefixAllTypesOfListsBuilderApi
from openapi_client.api.configuration_policy_data_prefix_list_builder_api import ConfigurationPolicyDataPrefixListBuilderApi
from openapi_client.api.configuration_policy_data_prefix_and_fqdn_all_types_of_lists_builder_api import ConfigurationPolicyDataPrefixAndFQDNAllTypesOfListsBuilderApi
from openapi_client.api.configuration_policy_device_access_list_definition_builder_api import ConfigurationPolicyDeviceAccessListDefinitionBuilderApi
from openapi_client.api.configuration_policy_dial_peer_definition_builder_api import ConfigurationPolicyDialPeerDefinitionBuilderApi
from openapi_client.api.configuration_policy_expanded_community_list_builder_api import ConfigurationPolicyExpandedCommunityListBuilderApi
from openapi_client.api.configuration_policy_extended_community_list_builder_api import ConfigurationPolicyExtendedCommunityListBuilderApi
from openapi_client.api.configuration_policy_fxo_port_definition_builder_api import ConfigurationPolicyFXOPortDefinitionBuilderApi
from openapi_client.api.configuration_policy_fxsdid_port_definition_builder_api import ConfigurationPolicyFXSDIDPortDefinitionBuilderApi
from openapi_client.api.configuration_policy_fxs_port_definition_builder_api import ConfigurationPolicyFXSPortDefinitionBuilderApi
from openapi_client.api.configuration_policy_fax_protocol_list_builder_api import ConfigurationPolicyFaxProtocolListBuilderApi
from openapi_client.api.configuration_policy_forwarding_class_list_builder_api import ConfigurationPolicyForwardingClassListBuilderApi
from openapi_client.api.configuration_policy_geo_location_builder_api import ConfigurationPolicyGeoLocationBuilderApi
from openapi_client.api.configuration_policy_hub_and_spoke_definition_builder_api import ConfigurationPolicyHubAndSpokeDefinitionBuilderApi
from openapi_client.api.configuration_policy_ips_signature_list_builder_api import ConfigurationPolicyIPSSignatureListBuilderApi
from openapi_client.api.configuration_policy_ipv6_access_list_definition_builder_api import ConfigurationPolicyIPv6AccessListDefinitionBuilderApi
from openapi_client.api.configuration_policy_ipv6_device_access_list_definition_builder_api import ConfigurationPolicyIPv6DeviceAccessListDefinitionBuilderApi
from openapi_client.api.configuration_policy_ipv6_prefix_list_builder_api import ConfigurationPolicyIPv6PrefixListBuilderApi
from openapi_client.api.configuration_policy_intrusion_prevention_definition_builder_api import ConfigurationPolicyIntrusionPreventionDefinitionBuilderApi
from openapi_client.api.configuration_policy_list_builder_api import ConfigurationPolicyListBuilderApi
from openapi_client.api.configuration_policy_local_domain_definition_builder_api import ConfigurationPolicyLocalDomainDefinitionBuilderApi
from openapi_client.api.configuration_policy_local_domain_name_list_builder_api import ConfigurationPolicyLocalDomainNameListBuilderApi
from openapi_client.api.configuration_policy_media_profile_list_builder_api import ConfigurationPolicyMediaProfileListBuilderApi
from openapi_client.api.configuration_policy_mesh_definition_builder_api import ConfigurationPolicyMeshDefinitionBuilderApi
from openapi_client.api.configuration_policy_mirror_builder_api import ConfigurationPolicyMirrorBuilderApi
from openapi_client.api.configuration_policy_modem_passthrough_list_builder_api import ConfigurationPolicyModemPassthroughListBuilderApi
from openapi_client.api.configuration_policy_priisdn_port_definition_builder_api import ConfigurationPolicyPRIISDNPortDefinitionBuilderApi
from openapi_client.api.configuration_policy_policer_class_builder_api import ConfigurationPolicyPolicerClassBuilderApi
from openapi_client.api.configuration_policy_port_list_builder_api import ConfigurationPolicyPortListBuilderApi
from openapi_client.api.configuration_policy_prefix_list_builder_api import ConfigurationPolicyPrefixListBuilderApi
from openapi_client.api.configuration_policy_prefix_for_all_types_of_lists_builder_api import ConfigurationPolicyPrefixForAllTypesOfListsBuilderApi
from openapi_client.api.configuration_policy_protocol_name_list_builder_api import ConfigurationPolicyProtocolNameListBuilderApi
from openapi_client.api.configuration_policy_qos_map_definition_builder_api import ConfigurationPolicyQosMapDefinitionBuilderApi
from openapi_client.api.configuration_policy_region_list_builder_api import ConfigurationPolicyRegionListBuilderApi
from openapi_client.api.configuration_policy_rewrite_rule_definition_builder_api import ConfigurationPolicyRewriteRuleDefinitionBuilderApi
from openapi_client.api.configuration_policy_sla_class_builder_api import ConfigurationPolicySLAClassBuilderApi
from openapi_client.api.configuration_policy_secure_internet_gateway_data_centers_builder_api import ConfigurationPolicySecureInternetGatewayDataCentersBuilderApi
from openapi_client.api.configuration_policy_security_assembler_api import ConfigurationPolicySecurityAssemblerApi
from openapi_client.api.configuration_policy_site_list_builder_api import ConfigurationPolicySiteListBuilderApi
from openapi_client.api.configuration_policy_supervisory_disc_list_builder_api import ConfigurationPolicySupervisoryDiscListBuilderApi
from openapi_client.api.configuration_policy_tloc_list_builder_api import ConfigurationPolicyTLOCListBuilderApi
from openapi_client.api.configuration_policy_threat_grid_api_key_api import ConfigurationPolicyThreatGridApiKeyApi
from openapi_client.api.configuration_policy_translation_profile_list_builder_api import ConfigurationPolicyTranslationProfileListBuilderApi
from openapi_client.api.configuration_policy_translation_rules_list_builder_api import ConfigurationPolicyTranslationRulesListBuilderApi
from openapi_client.api.configuration_policy_trunk_group_list_builder_api import ConfigurationPolicyTrunkGroupListBuilderApi
from openapi_client.api.configuration_policy_url_black_list_builder_api import ConfigurationPolicyURLBlackListBuilderApi
from openapi_client.api.configuration_policy_url_filtering_definition_builder_api import ConfigurationPolicyURLFilteringDefinitionBuilderApi
from openapi_client.api.configuration_policy_url_white_list_builder_api import ConfigurationPolicyURLWhiteListBuilderApi
from openapi_client.api.configuration_policy_umbrella_data_builder_api import ConfigurationPolicyUmbrellaDataBuilderApi
from openapi_client.api.configuration_policy_vpn_list_builder_api import ConfigurationPolicyVPNListBuilderApi
from openapi_client.api.configuration_policy_vpn_membership_group_definition_builder_api import ConfigurationPolicyVPNMembershipGroupDefinitionBuilderApi
from openapi_client.api.configuration_policy_vpn_qos_map_definition_builder_api import ConfigurationPolicyVPNQosMapDefinitionBuilderApi
from openapi_client.api.configuration_policy_voice_assembler_api import ConfigurationPolicyVoiceAssemblerApi
from openapi_client.api.configuration_policy_zone_based_firewall_definition_builder_api import ConfigurationPolicyZoneBasedFirewallDefinitionBuilderApi
from openapi_client.api.configuration_policy_zone_list_builder_api import ConfigurationPolicyZoneListBuilderApi
from openapi_client.api.configuration_policy_v_edge_assembler_api import ConfigurationPolicyVEdgeAssemblerApi
from openapi_client.api.configuration_policy_v_edge_route_definition_builder_api import ConfigurationPolicyVEdgeRouteDefinitionBuilderApi
from openapi_client.api.configuration_policy_v_smart_assembler_api import ConfigurationPolicyVSmartAssemblerApi
from openapi_client.api.configuration_pre_upgrade_check_status_api import ConfigurationPreUpgradeCheckStatusApi
from openapi_client.api.configuration_quick_connect_api import ConfigurationQuickConnectApi
from openapi_client.api.configuration_rule_set_definition_api import ConfigurationRuleSetDefinitionApi
from openapi_client.api.configuration_ssl_decryption_policy_definition_builder_api import ConfigurationSSLDecryptionPolicyDefinitionBuilderApi
from openapi_client.api.configuration_ssl_decryption_utd_profile_definition_api import ConfigurationSSLDecryptionUTDProfileDefinitionApi
from openapi_client.api.configuration_secure_internet_gateway_tunnels_api import ConfigurationSecureInternetGatewayTunnelsApi
from openapi_client.api.configuration_security_group_definition_api import ConfigurationSecurityGroupDefinitionApi
from openapi_client.api.configuration_security_template_policy_api import ConfigurationSecurityTemplatePolicyApi
from openapi_client.api.configuration_segments_api import ConfigurationSegmentsApi
from openapi_client.api.configuration_settings_api import ConfigurationSettingsApi
from openapi_client.api.configuration_software_actions_api import ConfigurationSoftwareActionsApi
from openapi_client.api.configuration_template_configuration_api import ConfigurationTemplateConfigurationApi
from openapi_client.api.configuration_template_lock_api import ConfigurationTemplateLockApi
from openapi_client.api.configuration_template_master_api import ConfigurationTemplateMasterApi
from openapi_client.api.configuration_topology_api import ConfigurationTopologyApi
from openapi_client.api.configuration_voice_template_policy_api import ConfigurationVoiceTemplatePolicyApi
from openapi_client.api.configuration_v_edge_template_policy_api import ConfigurationVEdgeTemplatePolicyApi
from openapi_client.api.configuration_v_smart_template_policy_api import ConfigurationVSmartTemplatePolicyApi
from openapi_client.api.data_collection_agent_api import DataCollectionAgentApi
from openapi_client.api.deployment_mode_api import DeploymentModeApi
from openapi_client.api.device_messaging_api import DeviceMessagingApi
from openapi_client.api.device_network_api import DeviceNetworkApi
from openapi_client.api.locale_api import LocaleApi
from openapi_client.api.mdp_config_object_api import MDPConfigObjectApi
from openapi_client.api.mdp_device_sharing_api import MDPDeviceSharingApi
from openapi_client.api.mdp_internal_policy_management_api import MDPInternalPolicyManagementApi
from openapi_client.api.mdp_offboarding_api import MDPOffboardingApi
from openapi_client.api.mdp_onboarding_api import MDPOnboardingApi
from openapi_client.api.mdp_policy_management_api import MDPPolicyManagementApi
from openapi_client.api.msla_api import MSLAApi
from openapi_client.api.monitoring_art_api import MonitoringARTApi
from openapi_client.api.monitoring_alarms_details_api import MonitoringAlarmsDetailsApi
from openapi_client.api.monitoring_app_hosting_api import MonitoringAppHostingApi
from openapi_client.api.monitoring_app_hosting_interface_api import MonitoringAppHostingInterfaceApi
from openapi_client.api.monitoring_application_aware_routing_api import MonitoringApplicationAwareRoutingApi
from openapi_client.api.monitoring_application_aware_routing_statistics_api import MonitoringApplicationAwareRoutingStatisticsApi
from openapi_client.api.monitoring_bfd_api import MonitoringBFDApi
from openapi_client.api.monitoring_bridge_interface_api import MonitoringBridgeInterfaceApi
from openapi_client.api.monitoring_bridge_mac_api import MonitoringBridgeMacApi
from openapi_client.api.monitoring_cellular_eiolte_api import MonitoringCellularEIOLTEApi
from openapi_client.api.monitoring_cflowd_api import MonitoringCflowdApi
from openapi_client.api.monitoring_cflowd_flows_api import MonitoringCflowdFlowsApi
from openapi_client.api.monitoring_cloud_express_api import MonitoringCloudExpressApi
from openapi_client.api.monitoring_colocation_cluster_api import MonitoringColocationClusterApi
from openapi_client.api.monitoring_dpi_api import MonitoringDPIApi
from openapi_client.api.monitoring_dpion_demand_troubleshooting_api import MonitoringDPIOnDemandTroubleshootingApi
from openapi_client.api.monitoring_device_details_api import MonitoringDeviceDetailsApi
from openapi_client.api.monitoring_device_statistics_api import MonitoringDeviceStatisticsApi
from openapi_client.api.monitoring_device_statistics_details_api import MonitoringDeviceStatisticsDetailsApi
from openapi_client.api.monitoring_endpoint_tracker_status_api import MonitoringEndpointTrackerStatusApi
from openapi_client.api.monitoring_events_api import MonitoringEventsApi
from openapi_client.api.monitoring_flowlog_api import MonitoringFlowlogApi
from openapi_client.api.monitoring_health_api import MonitoringHealthApi
from openapi_client.api.monitoring_health_devices_api import MonitoringHealthDevicesApi
from openapi_client.api.monitoring_ips_alert_api import MonitoringIPsAlertApi
from openapi_client.api.monitoring_interface_statistics_api import MonitoringInterfaceStatisticsApi
from openapi_client.api.monitoring_qo_s_api import MonitoringQoSApi
from openapi_client.api.monitoring_security_unified_logging_connection_events_api import MonitoringSecurityUnifiedLoggingConnectionEventsApi
from openapi_client.api.monitoring_server_info_api import MonitoringServerInfoApi
from openapi_client.api.monitoring_service_chain_statistics_api import MonitoringServiceChainStatisticsApi
from openapi_client.api.monitoring_stats_download_api import MonitoringStatsDownloadApi
from openapi_client.api.monitoring_stats_processing_api import MonitoringStatsProcessingApi
from openapi_client.api.monitoring_status_api import MonitoringStatusApi
from openapi_client.api.monitoring_system_status_stats_api import MonitoringSystemStatusStatsApi
from openapi_client.api.monitoring_url_filtering_api import MonitoringURLFilteringApi
from openapi_client.api.monitoring_umbrella_api import MonitoringUmbrellaApi
from openapi_client.api.monitoring_umbrella_patterns_api import MonitoringUmbrellaPatternsApi
from openapi_client.api.monitoring_wlan_client_info_api import MonitoringWlanClientInfoApi
from openapi_client.api.multitenant_apis_provider_api import MultitenantAPIsProviderApi
from openapi_client.api.partner_aci_policy_builder_api import PartnerACIPolicyBuilderApi
from openapi_client.api.partner_dnacsdaapi_api import PartnerDNACSDAAPIApi
from openapi_client.api.partner_registration_api import PartnerRegistrationApi
from openapi_client.api.partner_wcm_configs_api import PartnerWCMConfigsApi
from openapi_client.api.real_time_monitoring_aaa_api import RealTimeMonitoringAAAApi
from openapi_client.api.real_time_monitoring_arp_api import RealTimeMonitoringARPApi
from openapi_client.api.real_time_monitoring_app_hosting_api import RealTimeMonitoringAppHostingApi
from openapi_client.api.real_time_monitoring_app_logs_api import RealTimeMonitoringAppLogsApi
from openapi_client.api.real_time_monitoring_application_aware_route_api import RealTimeMonitoringApplicationAwareRouteApi
from openapi_client.api.real_time_monitoring_appqoe_api import RealTimeMonitoringAppqoeApi
from openapi_client.api.real_time_monitoring_bfd_api import RealTimeMonitoringBFDApi
from openapi_client.api.real_time_monitoring_bgp_api import RealTimeMonitoringBGPApi
from openapi_client.api.real_time_monitoring_bridge_api import RealTimeMonitoringBridgeApi
from openapi_client.api.real_time_monitoring_cfm_api import RealTimeMonitoringCFMApi
from openapi_client.api.real_time_monitoring_cellular_api import RealTimeMonitoringCellularApi
from openapi_client.api.real_time_monitoring_cellular_aon_ipsec_interface_api import RealTimeMonitoringCellularAONIpsecInterfaceApi
from openapi_client.api.real_time_monitoring_cellular_eiolte_connection_service_api import RealTimeMonitoringCellularEIOLTEConnectionServiceApi
from openapi_client.api.real_time_monitoring_cellular_eiolte_hardware_service_api import RealTimeMonitoringCellularEIOLTEHardwareServiceApi
from openapi_client.api.real_time_monitoring_cellular_eiolte_network_service_api import RealTimeMonitoringCellularEIOLTENetworkServiceApi
from openapi_client.api.real_time_monitoring_cellular_eiolte_sim_service_api import RealTimeMonitoringCellularEIOLTESimServiceApi
from openapi_client.api.real_time_monitoring_cloud_express_api import RealTimeMonitoringCloudExpressApi
from openapi_client.api.real_time_monitoring_container_lifecycle_api import RealTimeMonitoringContainerLifecycleApi
from openapi_client.api.real_time_monitoring_crash_log_api import RealTimeMonitoringCrashLogApi
from openapi_client.api.real_time_monitoring_dhcp_api import RealTimeMonitoringDHCPApi
from openapi_client.api.real_time_monitoring_dot1x_api import RealTimeMonitoringDOT1xApi
from openapi_client.api.real_time_monitoring_dpi_api import RealTimeMonitoringDPIApi
from openapi_client.api.real_time_monitoring_dre_api import RealTimeMonitoringDREApi
from openapi_client.api.real_time_monitoring_device_api import RealTimeMonitoringDeviceApi
from openapi_client.api.real_time_monitoring_device_control_api import RealTimeMonitoringDeviceControlApi
from openapi_client.api.real_time_monitoring_device_feature_list_api import RealTimeMonitoringDeviceFeatureListApi
from openapi_client.api.real_time_monitoring_device_system_stats_api import RealTimeMonitoringDeviceSystemStatsApi
from openapi_client.api.real_time_monitoring_downloaded_images_api import RealTimeMonitoringDownloadedImagesApi
from openapi_client.api.real_time_monitoring_dual_static_route_tracker_service_api import RealTimeMonitoringDualStaticRouteTrackerServiceApi
from openapi_client.api.real_time_monitoring_eigrp_api import RealTimeMonitoringEIGRPApi
from openapi_client.api.real_time_monitoring_endpoint_tracker_group_service_api import RealTimeMonitoringEndpointTrackerGroupServiceApi
from openapi_client.api.real_time_monitoring_endpoint_tracker_service_api import RealTimeMonitoringEndpointTrackerServiceApi
from openapi_client.api.real_time_monitoring_geo_fencing_api import RealTimeMonitoringGeoFencingApi
from openapi_client.api.real_time_monitoring_hardware_api import RealTimeMonitoringHardwareApi
from openapi_client.api.real_time_monitoring_igmp_api import RealTimeMonitoringIGMPApi
from openapi_client.api.real_time_monitoring_ip_api import RealTimeMonitoringIPApi
from openapi_client.api.real_time_monitoring_i_psec_api import RealTimeMonitoringIPsecApi
from openapi_client.api.real_time_monitoring_ipv4_fib_api import RealTimeMonitoringIPv4FIBApi
from openapi_client.api.real_time_monitoring_ipv6_fib_api import RealTimeMonitoringIPv6FIBApi
from openapi_client.api.real_time_monitoring_ipv6_neighbours_api import RealTimeMonitoringIPv6NeighboursApi
from openapi_client.api.real_time_monitoring_interface_api import RealTimeMonitoringInterfaceApi
from openapi_client.api.real_time_monitoring_license_info_api import RealTimeMonitoringLicenseInfoApi
from openapi_client.api.real_time_monitoring_multicast_api import RealTimeMonitoringMulticastApi
from openapi_client.api.real_time_monitoring_nms_api import RealTimeMonitoringNMSApi
from openapi_client.api.real_time_monitoring_ntp_api import RealTimeMonitoringNTPApi
from openapi_client.api.real_time_monitoring_network_hub_resources_api import RealTimeMonitoringNetworkHubResourcesApi
from openapi_client.api.real_time_monitoring_omp_api import RealTimeMonitoringOMPApi
from openapi_client.api.real_time_monitoring_ospf_api import RealTimeMonitoringOSPFApi
from openapi_client.api.real_time_monitoring_orchestrator_api import RealTimeMonitoringOrchestratorApi
from openapi_client.api.real_time_monitoring_pim_api import RealTimeMonitoringPIMApi
from openapi_client.api.real_time_monitoring_pppo_e_api import RealTimeMonitoringPPPoEApi
from openapi_client.api.real_time_monitoring_policer_api import RealTimeMonitoringPolicerApi
from openapi_client.api.real_time_monitoring_policy_api import RealTimeMonitoringPolicyApi
from openapi_client.api.real_time_monitoring_rbac_api import RealTimeMonitoringRBACApi
from openapi_client.api.real_time_monitoring_reboot_history_api import RealTimeMonitoringRebootHistoryApi
from openapi_client.api.real_time_monitoring_sdwan_statistics_api import RealTimeMonitoringSDWANStatisticsApi
from openapi_client.api.real_time_monitoring_sfp_api import RealTimeMonitoringSFPApi
from openapi_client.api.real_time_monitoring_sig_api import RealTimeMonitoringSIGApi
from openapi_client.api.real_time_monitoring_security_api import RealTimeMonitoringSecurityApi
from openapi_client.api.real_time_monitoring_show_on_demand_local_api import RealTimeMonitoringShowOnDemandLocalApi
from openapi_client.api.real_time_monitoring_show_on_demand_remote_api import RealTimeMonitoringShowOnDemandRemoteApi
from openapi_client.api.real_time_monitoring_software_api import RealTimeMonitoringSoftwareApi
from openapi_client.api.real_time_monitoring_sslproxy_api import RealTimeMonitoringSslproxyApi
from openapi_client.api.real_time_monitoring_static_route_tracker_service_api import RealTimeMonitoringStaticRouteTrackerServiceApi
from openapi_client.api.real_time_monitoring_system_api import RealTimeMonitoringSystemApi
from openapi_client.api.real_time_monitoring_tcp_optimization_api import RealTimeMonitoringTCPOptimizationApi
from openapi_client.api.real_time_monitoring_tcpproxy_api import RealTimeMonitoringTcpproxyApi
from openapi_client.api.real_time_monitoring_transport_api import RealTimeMonitoringTransportApi
from openapi_client.api.real_time_monitoring_trustsec_api import RealTimeMonitoringTrustsecApi
from openapi_client.api.real_time_monitoring_tunnel_api import RealTimeMonitoringTunnelApi
from openapi_client.api.real_time_monitoring_utd_api import RealTimeMonitoringUTDApi
from openapi_client.api.real_time_monitoring_ucse_api import RealTimeMonitoringUcseApi
from openapi_client.api.real_time_monitoring_umbrella_api import RealTimeMonitoringUmbrellaApi
from openapi_client.api.real_time_monitoring_vdsl_service_api import RealTimeMonitoringVDSLServiceApi
from openapi_client.api.real_time_monitoring_vm_api import RealTimeMonitoringVMApi
from openapi_client.api.real_time_monitoring_vpn_api import RealTimeMonitoringVPNApi
from openapi_client.api.real_time_monitoring_vrrp_api import RealTimeMonitoringVRRPApi
from openapi_client.api.real_time_monitoring_voice_api import RealTimeMonitoringVoiceApi
from openapi_client.api.real_time_monitoring_wlan_api import RealTimeMonitoringWLANApi
from openapi_client.api.real_time_monitoring_wireless_api import RealTimeMonitoringWirelessApi
from openapi_client.api.resource_pool_api import ResourcePoolApi
from openapi_client.api.sdavc_cloud_connector_api import SDAVCCloudConnectorApi
from openapi_client.api.sdavc_domain_based_app_rules_api import SDAVCDomainBasedAppRulesApi
from openapi_client.api.sdavcip_address_based_app_rules_api import SDAVCIPAddressBasedAppRulesApi
from openapi_client.api.scheduled_backup_restore_api import ScheduledBackupRestoreApi
from openapi_client.api.smart_license_api import SmartLicenseApi
from openapi_client.api.system_cloud_service_api import SystemCloudServiceApi
from openapi_client.api.system_cloud_service_webex_api import SystemCloudServiceWebexApi
from openapi_client.api.system_container_api import SystemContainerApi
from openapi_client.api.system_reverse_proxy_api import SystemReverseProxyApi
from openapi_client.api.tag_api import TagApi
from openapi_client.api.tenant_backup_restore_api import TenantBackupRestoreApi
from openapi_client.api.tenant_management_api import TenantManagementApi
from openapi_client.api.tenant_migration_api import TenantMigrationApi
from openapi_client.api.troubleshooting_tools_device_connectivity_api import TroubleshootingToolsDeviceConnectivityApi
from openapi_client.api.troubleshooting_tools_device_group_api import TroubleshootingToolsDeviceGroupApi
from openapi_client.api.troubleshooting_tools_diagnostics_api import TroubleshootingToolsDiagnosticsApi
from openapi_client.api.umbrella_api import UmbrellaApi
from openapi_client.api.utility_configuration_db_api import UtilityConfigurationDBApi
from openapi_client.api.utility_logging_api import UtilityLoggingApi
from openapi_client.api.utility_security_api import UtilitySecurityApi
from openapi_client.api.workflow_management_api import WorkflowManagementApi
from openapi_client.api.default_api import DefaultApi
