"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import openapi_client
from openapi_client.model.cellular import Cellular
from openapi_client.model.ethernet import Ethernet
from openapi_client.model.global_settings import GlobalSettings
from openapi_client.model.network_protocol import NetworkProtocol
from openapi_client.model.security_policy import SecurityPolicy
from openapi_client.model.variable import Variable
from openapi_client.model.vpn import Vpn
from openapi_client.model.wifi import Wifi
globals()['Cellular'] = Cellular
globals()['Ethernet'] = Ethernet
globals()['GlobalSettings'] = GlobalSettings
globals()['NetworkProtocol'] = NetworkProtocol
globals()['SecurityPolicy'] = SecurityPolicy
globals()['Variable'] = Variable
globals()['Vpn'] = Vpn
globals()['Wifi'] = Wifi
from openapi_client.model.profile_parcel import ProfileParcel


class TestProfileParcel(unittest.TestCase):
    """ProfileParcel unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testProfileParcel(self):
        """Test ProfileParcel"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ProfileParcel()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
