"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.real_time_monitoring_ipv6_neighbours_api import RealTimeMonitoringIPv6NeighboursApi  # noqa: E501


class TestRealTimeMonitoringIPv6NeighboursApi(unittest.TestCase):
    """RealTimeMonitoringIPv6NeighboursApi unit test stubs"""

    def setUp(self):
        self.api = RealTimeMonitoringIPv6NeighboursApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_ipv6_interface(self):
        """Test case for get_ipv6_interface

        """
        pass


if __name__ == '__main__':
    unittest.main()
