"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.real_time_monitoring_ospf_api import RealTimeMonitoringOSPFApi  # noqa: E501


class TestRealTimeMonitoringOSPFApi(unittest.TestCase):
    """RealTimeMonitoringOSPFApi unit test stubs"""

    def setUp(self):
        self.api = RealTimeMonitoringOSPFApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_ospf_database_external(self):
        """Test case for create_ospf_database_external

        """
        pass

    def test_create_ospf_database_list(self):
        """Test case for create_ospf_database_list

        """
        pass

    def test_create_ospf_database_summary_list(self):
        """Test case for create_ospf_database_summary_list

        """
        pass

    def test_create_ospf_interface(self):
        """Test case for create_ospf_interface

        """
        pass

    def test_create_ospf_neighbors(self):
        """Test case for create_ospf_neighbors

        """
        pass

    def test_create_ospf_process(self):
        """Test case for create_ospf_process

        """
        pass

    def test_create_ospf_routes_list(self):
        """Test case for create_ospf_routes_list

        """
        pass

    def test_create_ospfv3_interface(self):
        """Test case for create_ospfv3_interface

        """
        pass

    def test_create_ospfv3_neighbors(self):
        """Test case for create_ospfv3_neighbors

        """
        pass


if __name__ == '__main__':
    unittest.main()
