"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.monitoring_device_statistics_details_api import MonitoringDeviceStatisticsDetailsApi  # noqa: E501


class TestMonitoringDeviceStatisticsDetailsApi(unittest.TestCase):
    """MonitoringDeviceStatisticsDetailsApi unit test stubs"""

    def setUp(self):
        self.api = MonitoringDeviceStatisticsDetailsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_generate_device_statistics_data(self):
        """Test case for generate_device_statistics_data

        """
        pass

    def test_get_active_alarms(self):
        """Test case for get_active_alarms

        """
        pass

    def test_get_count_with_state_data_type(self):
        """Test case for get_count_with_state_data_type

        """
        pass

    def test_get_stat_data_fields_by_state_data_type(self):
        """Test case for get_stat_data_fields_by_state_data_type

        """
        pass

    def test_get_statistics_type(self):
        """Test case for get_statistics_type

        """
        pass


if __name__ == '__main__':
    unittest.main()
