"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.configuration_dashboard_status_api import ConfigurationDashboardStatusApi  # noqa: E501


class TestConfigurationDashboardStatusApi(unittest.TestCase):
    """ConfigurationDashboardStatusApi unit test stubs"""

    def setUp(self):
        self.api = ConfigurationDashboardStatusApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_cancel_pending_tasks(self):
        """Test case for cancel_pending_tasks

        """
        pass

    def test_clean_status(self):
        """Test case for clean_status

        """
        pass

    def test_delete_status(self):
        """Test case for delete_status

        """
        pass

    def test_find_running_tasks(self):
        """Test case for find_running_tasks

        """
        pass

    def test_find_status(self):
        """Test case for find_status

        """
        pass

    def test_get_active_task_count(self):
        """Test case for get_active_task_count

        """
        pass

    def test_get_clean_status(self):
        """Test case for get_clean_status

        """
        pass


if __name__ == '__main__':
    unittest.main()
