"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.real_time_monitoring_appqoe_api import RealTimeMonitoringAppqoeApi  # noqa: E501


class TestRealTimeMonitoringAppqoeApi(unittest.TestCase):
    """RealTimeMonitoringAppqoeApi unit test stubs"""

    def setUp(self):
        self.api = RealTimeMonitoringAppqoeApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_appqoe_cluster_summary(self):
        """Test case for get_appqoe_cluster_summary

        """
        pass

    def test_get_appqoe_error_recent(self):
        """Test case for get_appqoe_error_recent

        """
        pass

    def test_get_appqoe_flow_closed_error(self):
        """Test case for get_appqoe_flow_closed_error

        """
        pass

    def test_get_appqoe_hput_stats(self):
        """Test case for get_appqoe_hput_stats

        """
        pass

    def test_get_appqoe_nat_stats(self):
        """Test case for get_appqoe_nat_stats

        """
        pass

    def test_get_appqoe_rm_resources(self):
        """Test case for get_appqoe_rm_resources

        """
        pass

    def test_get_appqoe_rm_stats(self):
        """Test case for get_appqoe_rm_stats

        """
        pass

    def test_get_appqoe_service_controllers(self):
        """Test case for get_appqoe_service_controllers

        """
        pass

    def test_get_appqoe_services_status(self):
        """Test case for get_appqoe_services_status

        """
        pass

    def test_get_appqoe_sppi_pipe_stats(self):
        """Test case for get_appqoe_sppi_pipe_stats

        """
        pass

    def test_get_appqoe_sppi_queue_stats(self):
        """Test case for get_appqoe_sppi_queue_stats

        """
        pass

    def test_get_appqoe_status(self):
        """Test case for get_appqoe_status

        """
        pass


if __name__ == '__main__':
    unittest.main()
