"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.configuration_feature_profile_mobility_api import ConfigurationFeatureProfileMobilityApi  # noqa: E501


class TestConfigurationFeatureProfileMobilityApi(unittest.TestCase):
    """ConfigurationFeatureProfileMobilityApi unit test stubs"""

    def setUp(self):
        self.api = ConfigurationFeatureProfileMobilityApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_basic_profile_parcel_for_mobility(self):
        """Test case for create_basic_profile_parcel_for_mobility

        """
        pass

    def test_create_cellular_profile_parcel_for_mobility(self):
        """Test case for create_cellular_profile_parcel_for_mobility

        """
        pass

    def test_create_ethernet_profile_parcel_for_mobility(self):
        """Test case for create_ethernet_profile_parcel_for_mobility

        """
        pass

    def test_create_mobility_config_profile_parcel_for_cli(self):
        """Test case for create_mobility_config_profile_parcel_for_cli

        """
        pass

    def test_create_network_protocol_profile_parcel_for_mobility(self):
        """Test case for create_network_protocol_profile_parcel_for_mobility

        """
        pass

    def test_create_security_policy_profile_parcel_for_mobility(self):
        """Test case for create_security_policy_profile_parcel_for_mobility

        """
        pass

    def test_create_vpn_profile_parcel_for_mobility(self):
        """Test case for create_vpn_profile_parcel_for_mobility

        """
        pass

    def test_create_wifi_profile_parcel_for_mobility(self):
        """Test case for create_wifi_profile_parcel_for_mobility

        """
        pass

    def test_delete_a_cellular_profile_parcel_for_mobility(self):
        """Test case for delete_a_cellular_profile_parcel_for_mobility

        """
        pass

    def test_delete_a_vpn_profile_parcel_for_mobility(self):
        """Test case for delete_a_vpn_profile_parcel_for_mobility

        """
        pass

    def test_delete_basic_profile_parcel_for_mobility(self):
        """Test case for delete_basic_profile_parcel_for_mobility

        """
        pass

    def test_delete_ethernet_profile_parcel_for_system(self):
        """Test case for delete_ethernet_profile_parcel_for_system

        """
        pass

    def test_delete_mobility_config_profile_parcel_for_cli(self):
        """Test case for delete_mobility_config_profile_parcel_for_cli

        """
        pass

    def test_delete_network_protocol_profile_parcel_for_mobility(self):
        """Test case for delete_network_protocol_profile_parcel_for_mobility

        """
        pass

    def test_delete_security_policy_profile_parcel_for_mobility(self):
        """Test case for delete_security_policy_profile_parcel_for_mobility

        """
        pass

    def test_delete_wifi_profile_parcel_for_mobility(self):
        """Test case for delete_wifi_profile_parcel_for_mobility

        """
        pass

    def test_edit_basic_profile_parcel_for_mobility(self):
        """Test case for edit_basic_profile_parcel_for_mobility

        """
        pass

    def test_edit_cellular_profile_parcel_for_mobility(self):
        """Test case for edit_cellular_profile_parcel_for_mobility

        """
        pass

    def test_edit_ethernet_profile_parcel_for_system(self):
        """Test case for edit_ethernet_profile_parcel_for_system

        """
        pass

    def test_edit_mobility_config_profile_parcel_for_cli(self):
        """Test case for edit_mobility_config_profile_parcel_for_cli

        """
        pass

    def test_edit_network_protocol_profile_parcel_for_mobility(self):
        """Test case for edit_network_protocol_profile_parcel_for_mobility

        """
        pass

    def test_edit_security_policy_profile_parcel_for_mobility(self):
        """Test case for edit_security_policy_profile_parcel_for_mobility

        """
        pass

    def test_edit_vpn_profile_parcel_for_mobility(self):
        """Test case for edit_vpn_profile_parcel_for_mobility

        """
        pass

    def test_edit_wifi_profile_parcel_for_mobility(self):
        """Test case for edit_wifi_profile_parcel_for_mobility

        """
        pass

    def test_get_basic_profile_parcel_by_parcel_id_for_mobility(self):
        """Test case for get_basic_profile_parcel_by_parcel_id_for_mobility

        """
        pass

    def test_get_basic_profile_parcel_for_mobility(self):
        """Test case for get_basic_profile_parcel_for_mobility

        """
        pass

    def test_get_cellular_profile_parcel_for_mobility(self):
        """Test case for get_cellular_profile_parcel_for_mobility

        """
        pass

    def test_get_cellular_profile_parcel_list_for_mobility(self):
        """Test case for get_cellular_profile_parcel_list_for_mobility

        """
        pass

    def test_get_ethernet_profile_parcel(self):
        """Test case for get_ethernet_profile_parcel

        """
        pass

    def test_get_ethernet_profile_parcels(self):
        """Test case for get_ethernet_profile_parcels

        """
        pass

    def test_get_mobility_config_profile_parcel_by_parcel_id_for_cli(self):
        """Test case for get_mobility_config_profile_parcel_by_parcel_id_for_cli

        """
        pass

    def test_get_mobility_config_profile_parcel_for_cli(self):
        """Test case for get_mobility_config_profile_parcel_for_cli

        """
        pass

    def test_get_mobility_feature_profile_by_global_id(self):
        """Test case for get_mobility_feature_profile_by_global_id

        """
        pass

    def test_get_mobility_global_basic_parcel_schema_by_schema_type(self):
        """Test case for get_mobility_global_basic_parcel_schema_by_schema_type

        """
        pass

    def test_get_network_protocol_profile_parcel_for_mobility(self):
        """Test case for get_network_protocol_profile_parcel_for_mobility

        """
        pass

    def test_get_network_protocol_profile_parcel_list_for_mobility(self):
        """Test case for get_network_protocol_profile_parcel_list_for_mobility

        """
        pass

    def test_get_security_policy_profile_parcel_for_mobility(self):
        """Test case for get_security_policy_profile_parcel_for_mobility

        """
        pass

    def test_get_security_policy_profile_parcel_list_for_mobility(self):
        """Test case for get_security_policy_profile_parcel_list_for_mobility

        """
        pass

    def test_get_vpn_profile_parcel_for_mobility(self):
        """Test case for get_vpn_profile_parcel_for_mobility

        """
        pass

    def test_get_vpn_profile_parcel_list_for_mobility(self):
        """Test case for get_vpn_profile_parcel_list_for_mobility

        """
        pass

    def test_get_wifi_profile_parcel_for_mobility(self):
        """Test case for get_wifi_profile_parcel_for_mobility

        """
        pass

    def test_get_wifi_profile_parcel_list_for_mobility(self):
        """Test case for get_wifi_profile_parcel_list_for_mobility

        """
        pass


if __name__ == '__main__':
    unittest.main()
