"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.configuration_policy_custom_application_builder_api import ConfigurationPolicyCustomApplicationBuilderApi  # noqa: E501


class TestConfigurationPolicyCustomApplicationBuilderApi(unittest.TestCase):
    """ConfigurationPolicyCustomApplicationBuilderApi unit test stubs"""

    def setUp(self):
        self.api = ConfigurationPolicyCustomApplicationBuilderApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_custom_app(self):
        """Test case for create_custom_app

        """
        pass

    def test_delete_custom_app(self):
        """Test case for delete_custom_app

        """
        pass

    def test_edit_custom_app(self):
        """Test case for edit_custom_app

        """
        pass

    def test_get_custom_app_by_id(self):
        """Test case for get_custom_app_by_id

        """
        pass

    def test_get_custom_apps(self):
        """Test case for get_custom_apps

        """
        pass

    def test_map_traffic_profiles(self):
        """Test case for map_traffic_profiles

        """
        pass


if __name__ == '__main__':
    unittest.main()
