"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.troubleshooting_tools_diagnostics_api import TroubleshootingToolsDiagnosticsApi  # noqa: E501


class TestTroubleshootingToolsDiagnosticsApi(unittest.TestCase):
    """TroubleshootingToolsDiagnosticsApi unit test stubs"""

    def setUp(self):
        self.api = TroubleshootingToolsDiagnosticsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_clear_session(self):
        """Test case for clear_session

        """
        pass

    def test_disable_device_log(self):
        """Test case for disable_device_log

        """
        pass

    def test_disable_packet_capture_session(self):
        """Test case for disable_packet_capture_session

        """
        pass

    def test_disable_speed_test_session(self):
        """Test case for disable_speed_test_session

        """
        pass

    def test_download_debug_log(self):
        """Test case for download_debug_log

        """
        pass

    def test_download_file(self):
        """Test case for download_file

        """
        pass

    def test_force_stop_pcap_session(self):
        """Test case for force_stop_pcap_session

        """
        pass

    def test_form_post_packet_capture(self):
        """Test case for form_post_packet_capture

        """
        pass

    def test_get_aggregation_data_by_query27(self):
        """Test case for get_aggregation_data_by_query27

        """
        pass

    def test_get_aggregation_data_by_query28(self):
        """Test case for get_aggregation_data_by_query28

        """
        pass

    def test_get_concurrent_data(self):
        """Test case for get_concurrent_data

        """
        pass

    def test_get_concurrent_domain_data(self):
        """Test case for get_concurrent_domain_data

        """
        pass

    def test_get_count29(self):
        """Test case for get_count29

        """
        pass

    def test_get_count30(self):
        """Test case for get_count30

        """
        pass

    def test_get_count_post29(self):
        """Test case for get_count_post29

        """
        pass

    def test_get_count_post30(self):
        """Test case for get_count_post30

        """
        pass

    def test_get_db_schema(self):
        """Test case for get_db_schema

        """
        pass

    def test_get_device_log(self):
        """Test case for get_device_log

        """
        pass

    def test_get_domain_metric(self):
        """Test case for get_domain_metric

        """
        pass

    def test_get_file_download_status(self):
        """Test case for get_file_download_status

        """
        pass

    def test_get_finalized_data(self):
        """Test case for get_finalized_data

        """
        pass

    def test_get_finalized_domain_data(self):
        """Test case for get_finalized_domain_data

        """
        pass

    def test_get_flow_detail(self):
        """Test case for get_flow_detail

        """
        pass

    def test_get_flow_metric(self):
        """Test case for get_flow_metric

        """
        pass

    def test_get_interface_bandwidth(self):
        """Test case for get_interface_bandwidth

        """
        pass

    def test_get_log_type(self):
        """Test case for get_log_type

        """
        pass

    def test_get_monitor_state(self):
        """Test case for get_monitor_state

        """
        pass

    def test_get_nwpi_dscp(self):
        """Test case for get_nwpi_dscp

        """
        pass

    def test_get_nwpi_nbar_app_group(self):
        """Test case for get_nwpi_nbar_app_group

        """
        pass

    def test_get_nwpi_protocol(self):
        """Test case for get_nwpi_protocol

        """
        pass

    def test_get_packet_features(self):
        """Test case for get_packet_features

        """
        pass

    def test_get_post_aggregation_app_data_by_query26(self):
        """Test case for get_post_aggregation_app_data_by_query26

        """
        pass

    def test_get_post_aggregation_app_data_by_query27(self):
        """Test case for get_post_aggregation_app_data_by_query27

        """
        pass

    def test_get_post_aggregation_data_by_query27(self):
        """Test case for get_post_aggregation_data_by_query27

        """
        pass

    def test_get_post_aggregation_data_by_query28(self):
        """Test case for get_post_aggregation_data_by_query28

        """
        pass

    def test_get_post_stat_bulk_raw_data27(self):
        """Test case for get_post_stat_bulk_raw_data27

        """
        pass

    def test_get_post_stat_bulk_raw_data28(self):
        """Test case for get_post_stat_bulk_raw_data28

        """
        pass

    def test_get_session(self):
        """Test case for get_session

        """
        pass

    def test_get_session_info_capture(self):
        """Test case for get_session_info_capture

        """
        pass

    def test_get_session_info_log(self):
        """Test case for get_session_info_log

        """
        pass

    def test_get_sessions(self):
        """Test case for get_sessions

        """
        pass

    def test_get_speed_test(self):
        """Test case for get_speed_test

        """
        pass

    def test_get_speed_test_status(self):
        """Test case for get_speed_test_status

        """
        pass

    def test_get_stat_bulk_raw_data27(self):
        """Test case for get_stat_bulk_raw_data27

        """
        pass

    def test_get_stat_bulk_raw_data28(self):
        """Test case for get_stat_bulk_raw_data28

        """
        pass

    def test_get_stat_data_fields29(self):
        """Test case for get_stat_data_fields29

        """
        pass

    def test_get_stat_data_fields30(self):
        """Test case for get_stat_data_fields30

        """
        pass

    def test_get_stat_data_raw_data26(self):
        """Test case for get_stat_data_raw_data26

        """
        pass

    def test_get_stat_data_raw_data27(self):
        """Test case for get_stat_data_raw_data27

        """
        pass

    def test_get_stat_data_raw_data_as_csv27(self):
        """Test case for get_stat_data_raw_data_as_csv27

        """
        pass

    def test_get_stat_data_raw_data_as_csv28(self):
        """Test case for get_stat_data_raw_data_as_csv28

        """
        pass

    def test_get_stat_query_fields29(self):
        """Test case for get_stat_query_fields29

        """
        pass

    def test_get_stat_query_fields30(self):
        """Test case for get_stat_query_fields30

        """
        pass

    def test_get_stats_raw_data27(self):
        """Test case for get_stats_raw_data27

        """
        pass

    def test_get_stats_raw_data28(self):
        """Test case for get_stats_raw_data28

        """
        pass

    def test_get_thread_pools(self):
        """Test case for get_thread_pools

        """
        pass

    def test_get_trace_flow(self):
        """Test case for get_trace_flow

        """
        pass

    def test_get_trace_history(self):
        """Test case for get_trace_history

        """
        pass

    def test_get_vnic_info_by_vnf_id(self):
        """Test case for get_vnic_info_by_vnf_id

        """
        pass

    def test_monitor_start(self):
        """Test case for monitor_start

        """
        pass

    def test_monitor_stop(self):
        """Test case for monitor_stop

        """
        pass

    def test_process_device_status(self):
        """Test case for process_device_status

        """
        pass

    def test_renew_session_info(self):
        """Test case for renew_session_info

        """
        pass

    def test_save_speed_test_results(self):
        """Test case for save_speed_test_results

        """
        pass

    def test_search_device_log(self):
        """Test case for search_device_log

        """
        pass

    def test_start_pcap_session(self):
        """Test case for start_pcap_session

        """
        pass

    def test_start_speed_test(self):
        """Test case for start_speed_test

        """
        pass

    def test_stop_pcap_session(self):
        """Test case for stop_pcap_session

        """
        pass

    def test_stop_speed_test(self):
        """Test case for stop_speed_test

        """
        pass

    def test_stream_log(self):
        """Test case for stream_log

        """
        pass

    def test_trace_delete(self):
        """Test case for trace_delete

        """
        pass

    def test_trace_fin_flow_with_query(self):
        """Test case for trace_fin_flow_with_query

        """
        pass

    def test_trace_start(self):
        """Test case for trace_start

        """
        pass

    def test_trace_stop(self):
        """Test case for trace_stop

        """
        pass


if __name__ == '__main__':
    unittest.main()
