"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.cluster_management_api import ClusterManagementApi  # noqa: E501


class TestClusterManagementApi(unittest.TestCase):
    """ClusterManagementApi unit test stubs"""

    def setUp(self):
        self.api = ClusterManagementApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_or_update_user_credentials(self):
        """Test case for add_or_update_user_credentials

        """
        pass

    def test_add_vmanage(self):
        """Test case for add_vmanage

        """
        pass

    def test_check_if_cluster_locked(self):
        """Test case for check_if_cluster_locked

        """
        pass

    def test_configure_vmanage(self):
        """Test case for configure_vmanage

        """
        pass

    def test_edit_vmanage(self):
        """Test case for edit_vmanage

        """
        pass

    def test_get_cluster_workflow_version(self):
        """Test case for get_cluster_workflow_version

        """
        pass

    def test_get_configured_ip_list(self):
        """Test case for get_configured_ip_list

        """
        pass

    def test_get_connected_devices(self):
        """Test case for get_connected_devices

        """
        pass

    def test_get_connected_devices_per_tenant(self):
        """Test case for get_connected_devices_per_tenant

        """
        pass

    def test_get_tenancy_mode(self):
        """Test case for get_tenancy_mode

        """
        pass

    def test_get_tenants_list(self):
        """Test case for get_tenants_list

        """
        pass

    def test_get_v_manage_details(self):
        """Test case for get_v_manage_details

        """
        pass

    def test_health_details(self):
        """Test case for health_details

        """
        pass

    def test_health_status_info(self):
        """Test case for health_status_info

        """
        pass

    def test_health_summary(self):
        """Test case for health_summary

        """
        pass

    def test_is_cluster_ready(self):
        """Test case for is_cluster_ready

        """
        pass

    def test_list_vmanages(self):
        """Test case for list_vmanages

        """
        pass

    def test_node_properties(self):
        """Test case for node_properties

        """
        pass

    def test_perform_replication_and_rebalance_of_kafka_partitions(self):
        """Test case for perform_replication_and_rebalance_of_kafka_partitions

        """
        pass

    def test_remove_vmanage(self):
        """Test case for remove_vmanage

        """
        pass

    def test_set_tenancy_mode(self):
        """Test case for set_tenancy_mode

        """
        pass


if __name__ == '__main__':
    unittest.main()
