"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.monitoring_application_aware_routing_api import MonitoringApplicationAwareRoutingApi  # noqa: E501


class TestMonitoringApplicationAwareRoutingApi(unittest.TestCase):
    """MonitoringApplicationAwareRoutingApi unit test stubs"""

    def setUp(self):
        self.api = MonitoringApplicationAwareRoutingApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_aggregation_data_app_route(self):
        """Test case for get_aggregation_data_app_route

        """
        pass

    def test_get_aggregation_data_by_query2(self):
        """Test case for get_aggregation_data_by_query2

        """
        pass

    def test_get_approute_grid_stat(self):
        """Test case for get_approute_grid_stat

        """
        pass

    def test_get_count4(self):
        """Test case for get_count4

        """
        pass

    def test_get_count_post4(self):
        """Test case for get_count_post4

        """
        pass

    def test_get_post_aggregation_app_data_by_query2(self):
        """Test case for get_post_aggregation_app_data_by_query2

        """
        pass

    def test_get_post_aggregation_data_by_query2(self):
        """Test case for get_post_aggregation_data_by_query2

        """
        pass

    def test_get_post_stat_bulk_raw_data2(self):
        """Test case for get_post_stat_bulk_raw_data2

        """
        pass

    def test_get_stat_bulk_raw_data2(self):
        """Test case for get_stat_bulk_raw_data2

        """
        pass

    def test_get_stat_data_fields4(self):
        """Test case for get_stat_data_fields4

        """
        pass

    def test_get_stat_data_raw_data2(self):
        """Test case for get_stat_data_raw_data2

        """
        pass

    def test_get_stat_data_raw_data_as_csv2(self):
        """Test case for get_stat_data_raw_data_as_csv2

        """
        pass

    def test_get_stat_query_fields4(self):
        """Test case for get_stat_query_fields4

        """
        pass

    def test_get_stats_raw_data2(self):
        """Test case for get_stats_raw_data2

        """
        pass

    def test_get_transport_health(self):
        """Test case for get_transport_health

        """
        pass

    def test_get_transport_health_summary(self):
        """Test case for get_transport_health_summary

        """
        pass

    def test_get_tunnel(self):
        """Test case for get_tunnel

        """
        pass

    def test_get_tunnel_chart(self):
        """Test case for get_tunnel_chart

        """
        pass

    def test_get_tunnels(self):
        """Test case for get_tunnels

        """
        pass

    def test_get_tunnels_health(self):
        """Test case for get_tunnels_health

        """
        pass

    def test_get_tunnels_summary(self):
        """Test case for get_tunnels_summary

        """
        pass


if __name__ == '__main__':
    unittest.main()
