"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.configuration_configuration_group_api import ConfigurationConfigurationGroupApi  # noqa: E501


class TestConfigurationConfigurationGroupApi(unittest.TestCase):
    """ConfigurationConfigurationGroupApi unit test stubs"""

    def setUp(self):
        self.api = ConfigurationConfigurationGroupApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_config_group(self):
        """Test case for create_config_group

        """
        pass

    def test_create_config_group_association(self):
        """Test case for create_config_group_association

        """
        pass

    def test_create_config_group_device_variables(self):
        """Test case for create_config_group_device_variables

        """
        pass

    def test_create_config_group_device_variables1(self):
        """Test case for create_config_group_device_variables1

        """
        pass

    def test_delete_config_group(self):
        """Test case for delete_config_group

        """
        pass

    def test_delete_config_group_association(self):
        """Test case for delete_config_group_association

        """
        pass

    def test_deploy_config_group(self):
        """Test case for deploy_config_group

        """
        pass

    def test_edit_config_group(self):
        """Test case for edit_config_group

        """
        pass

    def test_get_cedge_config_group_schema_by_schema_type(self):
        """Test case for get_cedge_config_group_schema_by_schema_type

        """
        pass

    def test_get_config_group(self):
        """Test case for get_config_group

        """
        pass

    def test_get_config_group_association(self):
        """Test case for get_config_group_association

        """
        pass

    def test_get_config_group_by_solution(self):
        """Test case for get_config_group_by_solution

        """
        pass

    def test_get_config_group_device_configuration_preview(self):
        """Test case for get_config_group_device_configuration_preview

        """
        pass

    def test_get_config_group_device_variables(self):
        """Test case for get_config_group_device_variables

        """
        pass

    def test_update_config_group_association(self):
        """Test case for update_config_group_association

        """
        pass


if __name__ == '__main__':
    unittest.main()
