"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.configuration_device_software_update_api import ConfigurationDeviceSoftwareUpdateApi  # noqa: E501


class TestConfigurationDeviceSoftwareUpdateApi(unittest.TestCase):
    """ConfigurationDeviceSoftwareUpdateApi unit test stubs"""

    def setUp(self):
        self.api = ConfigurationDeviceSoftwareUpdateApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_download_package_file(self):
        """Test case for download_package_file

        """
        pass

    def test_edit_image_metadata(self):
        """Test case for edit_image_metadata

        """
        pass

    def test_get_image_metadata(self):
        """Test case for get_image_metadata

        """
        pass

    def test_get_upload_images_count(self):
        """Test case for get_upload_images_count

        """
        pass

    def test_install_pkg(self):
        """Test case for install_pkg

        """
        pass

    def test_process_software_image(self):
        """Test case for process_software_image

        """
        pass


if __name__ == '__main__':
    unittest.main()
