"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.configuration_multi_cloud_api import ConfigurationMultiCloudApi  # noqa: E501


class TestConfigurationMultiCloudApi(unittest.TestCase):
    """ConfigurationMultiCloudApi unit test stubs"""

    def setUp(self):
        self.api = ConfigurationMultiCloudApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_edge_global_settings(self):
        """Test case for add_edge_global_settings

        """
        pass

    def test_add_global_settings(self):
        """Test case for add_global_settings

        """
        pass

    def test_attach_sites(self):
        """Test case for attach_sites

        """
        pass

    def test_audit(self):
        """Test case for audit

        """
        pass

    def test_audit_dry_run(self):
        """Test case for audit_dry_run

        """
        pass

    def test_clean_up_all_connectivity_gateways_in_local_db(self):
        """Test case for clean_up_all_connectivity_gateways_in_local_db

        """
        pass

    def test_create_cgw(self):
        """Test case for create_cgw

        """
        pass

    def test_create_connectivity_gateway(self):
        """Test case for create_connectivity_gateway

        """
        pass

    def test_create_device_link(self):
        """Test case for create_device_link

        """
        pass

    def test_create_edge_connectivity(self):
        """Test case for create_edge_connectivity

        """
        pass

    def test_create_icgw(self):
        """Test case for create_icgw

        """
        pass

    def test_create_virtual_wan(self):
        """Test case for create_virtual_wan

        """
        pass

    def test_delete_account(self):
        """Test case for delete_account

        """
        pass

    def test_delete_cgw(self):
        """Test case for delete_cgw

        """
        pass

    def test_delete_connectivity_gateway(self):
        """Test case for delete_connectivity_gateway

        """
        pass

    def test_delete_device_link(self):
        """Test case for delete_device_link

        """
        pass

    def test_delete_edge_account(self):
        """Test case for delete_edge_account

        """
        pass

    def test_delete_edge_account1(self):
        """Test case for delete_edge_account1

        """
        pass

    def test_delete_edge_connectivity(self):
        """Test case for delete_edge_connectivity

        """
        pass

    def test_delete_icgw(self):
        """Test case for delete_icgw

        """
        pass

    def test_delete_virtual_wan(self):
        """Test case for delete_virtual_wan

        """
        pass

    def test_detach_sites1(self):
        """Test case for detach_sites1

        """
        pass

    def test_edge_audit(self):
        """Test case for edge_audit

        """
        pass

    def test_edge_audit_dry_run(self):
        """Test case for edge_audit_dry_run

        """
        pass

    def test_edit_tag(self):
        """Test case for edit_tag

        """
        pass

    def test_get_all_cloud_accounts(self):
        """Test case for get_all_cloud_accounts

        """
        pass

    def test_get_azure_network_virtual_appliances(self):
        """Test case for get_azure_network_virtual_appliances

        """
        pass

    def test_get_azure_nva_sku_list(self):
        """Test case for get_azure_nva_sku_list

        """
        pass

    def test_get_azure_resource_groups(self):
        """Test case for get_azure_resource_groups

        """
        pass

    def test_get_azure_virtual_hubs(self):
        """Test case for get_azure_virtual_hubs

        """
        pass

    def test_get_azure_virtual_wans(self):
        """Test case for get_azure_virtual_wans

        """
        pass

    def test_get_cgw_associated_mappings(self):
        """Test case for get_cgw_associated_mappings

        """
        pass

    def test_get_cgw_custom_setting_details(self):
        """Test case for get_cgw_custom_setting_details

        """
        pass

    def test_get_cgw_details(self):
        """Test case for get_cgw_details

        """
        pass

    def test_get_cgw_org_resources(self):
        """Test case for get_cgw_org_resources

        """
        pass

    def test_get_cgw_types(self):
        """Test case for get_cgw_types

        """
        pass

    def test_get_cgws(self):
        """Test case for get_cgws

        """
        pass

    def test_get_cloud_account_details(self):
        """Test case for get_cloud_account_details

        """
        pass

    def test_get_cloud_connected_sites(self):
        """Test case for get_cloud_connected_sites

        """
        pass

    def test_get_cloud_connected_sites1(self):
        """Test case for get_cloud_connected_sites1

        """
        pass

    def test_get_cloud_devices(self):
        """Test case for get_cloud_devices

        """
        pass

    def test_get_cloud_devices1(self):
        """Test case for get_cloud_devices1

        """
        pass

    def test_get_cloud_gateways(self):
        """Test case for get_cloud_gateways

        """
        pass

    def test_get_cloud_regions(self):
        """Test case for get_cloud_regions

        """
        pass

    def test_get_cloud_types(self):
        """Test case for get_cloud_types

        """
        pass

    def test_get_cloud_widget(self):
        """Test case for get_cloud_widget

        """
        pass

    def test_get_connectivity_gateway_creation_options(self):
        """Test case for get_connectivity_gateway_creation_options

        """
        pass

    def test_get_connectivity_gateways(self):
        """Test case for get_connectivity_gateways

        """
        pass

    def test_get_dashboard_edge_info(self):
        """Test case for get_dashboard_edge_info

        """
        pass

    def test_get_default_mapping_values(self):
        """Test case for get_default_mapping_values

        """
        pass

    def test_get_device_links(self):
        """Test case for get_device_links

        """
        pass

    def test_get_dl_port_speed(self):
        """Test case for get_dl_port_speed

        """
        pass

    def test_get_edge_account_details(self):
        """Test case for get_edge_account_details

        """
        pass

    def test_get_edge_accounts(self):
        """Test case for get_edge_accounts

        """
        pass

    def test_get_edge_billing_accounts(self):
        """Test case for get_edge_billing_accounts

        """
        pass

    def test_get_edge_connectivity_detail_by_name(self):
        """Test case for get_edge_connectivity_detail_by_name

        """
        pass

    def test_get_edge_connectivity_details(self):
        """Test case for get_edge_connectivity_details

        """
        pass

    def test_get_edge_gateways(self):
        """Test case for get_edge_gateways

        """
        pass

    def test_get_edge_global_settings(self):
        """Test case for get_edge_global_settings

        """
        pass

    def test_get_edge_locations_info(self):
        """Test case for get_edge_locations_info

        """
        pass

    def test_get_edge_mapping_tags(self):
        """Test case for get_edge_mapping_tags

        """
        pass

    def test_get_edge_types(self):
        """Test case for get_edge_types

        """
        pass

    def test_get_edge_wan_devices(self):
        """Test case for get_edge_wan_devices

        """
        pass

    def test_get_edge_widget(self):
        """Test case for get_edge_widget

        """
        pass

    def test_get_global_settings(self):
        """Test case for get_global_settings

        """
        pass

    def test_get_host_vpcs(self):
        """Test case for get_host_vpcs

        """
        pass

    def test_get_icgw_custom_setting_details(self):
        """Test case for get_icgw_custom_setting_details

        """
        pass

    def test_get_icgw_details(self):
        """Test case for get_icgw_details

        """
        pass

    def test_get_icgw_types(self):
        """Test case for get_icgw_types

        """
        pass

    def test_get_icgws(self):
        """Test case for get_icgws

        """
        pass

    def test_get_mapping_matrix(self):
        """Test case for get_mapping_matrix

        """
        pass

    def test_get_mapping_status(self):
        """Test case for get_mapping_status

        """
        pass

    def test_get_mapping_summary(self):
        """Test case for get_mapping_summary

        """
        pass

    def test_get_mapping_tags(self):
        """Test case for get_mapping_tags

        """
        pass

    def test_get_mapping_vpns(self):
        """Test case for get_mapping_vpns

        """
        pass

    def test_get_nva_security_rules(self):
        """Test case for get_nva_security_rules

        """
        pass

    def test_get_partner_ports(self):
        """Test case for get_partner_ports

        """
        pass

    def test_get_port_speed(self):
        """Test case for get_port_speed

        """
        pass

    def test_get_post_aggregation_data_by_query25(self):
        """Test case for get_post_aggregation_data_by_query25

        """
        pass

    def test_get_sites(self):
        """Test case for get_sites

        """
        pass

    def test_get_sites1(self):
        """Test case for get_sites1

        """
        pass

    def test_get_ssh_key_list(self):
        """Test case for get_ssh_key_list

        """
        pass

    def test_get_supported_edge_image_names(self):
        """Test case for get_supported_edge_image_names

        """
        pass

    def test_get_supported_edge_instance_size(self):
        """Test case for get_supported_edge_instance_size

        """
        pass

    def test_get_supported_instance_size(self):
        """Test case for get_supported_instance_size

        """
        pass

    def test_get_supported_loopback_cgw_colors(self):
        """Test case for get_supported_loopback_cgw_colors

        """
        pass

    def test_get_supported_software_image_list(self):
        """Test case for get_supported_software_image_list

        """
        pass

    def test_get_tunnel_names(self):
        """Test case for get_tunnel_names

        """
        pass

    def test_get_v_hubs(self):
        """Test case for get_v_hubs

        """
        pass

    def test_get_v_wans(self):
        """Test case for get_v_wans

        """
        pass

    def test_get_vpc_tags(self):
        """Test case for get_vpc_tags

        """
        pass

    def test_get_wan_devices(self):
        """Test case for get_wan_devices

        """
        pass

    def test_get_wan_interface_colors(self):
        """Test case for get_wan_interface_colors

        """
        pass

    def test_hostvpc_tagging(self):
        """Test case for hostvpc_tagging

        """
        pass

    def test_process_mapping(self):
        """Test case for process_mapping

        """
        pass

    def test_telemetry(self):
        """Test case for telemetry

        """
        pass

    def test_tunnel_scaling(self):
        """Test case for tunnel_scaling

        """
        pass

    def test_un_tag(self):
        """Test case for un_tag

        """
        pass

    def test_update_account(self):
        """Test case for update_account

        """
        pass

    def test_update_cgw(self):
        """Test case for update_cgw

        """
        pass

    def test_update_device_link(self):
        """Test case for update_device_link

        """
        pass

    def test_update_edge_account(self):
        """Test case for update_edge_account

        """
        pass

    def test_update_edge_connectivity(self):
        """Test case for update_edge_connectivity

        """
        pass

    def test_update_edge_global_settings(self):
        """Test case for update_edge_global_settings

        """
        pass

    def test_update_edge_locations_info(self):
        """Test case for update_edge_locations_info

        """
        pass

    def test_update_global_settings(self):
        """Test case for update_global_settings

        """
        pass

    def test_update_icgw(self):
        """Test case for update_icgw

        """
        pass

    def test_update_nva_security_rules(self):
        """Test case for update_nva_security_rules

        """
        pass

    def test_validate_account_add(self):
        """Test case for validate_account_add

        """
        pass

    def test_validate_account_update_credentials(self):
        """Test case for validate_account_update_credentials

        """
        pass

    def test_validate_edge_account_add(self):
        """Test case for validate_edge_account_add

        """
        pass

    def test_validate_edge_account_update_credentials(self):
        """Test case for validate_edge_account_update_credentials

        """
        pass


if __name__ == '__main__':
    unittest.main()
