"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.msla_api import MSLAApi  # noqa: E501


class TestMSLAApi(unittest.TestCase):
    """MSLAApi unit test stubs"""

    def setUp(self):
        self.api = MSLAApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_all_template(self):
        """Test case for get_all_template

        """
        pass

    def test_get_license_and_device_count(self):
        """Test case for get_license_and_device_count

        """
        pass

    def test_get_license_and_device_count1(self):
        """Test case for get_license_and_device_count1

        """
        pass

    def test_get_msla_devices(self):
        """Test case for get_msla_devices

        """
        pass

    def test_get_packaging_distribution_details(self):
        """Test case for get_packaging_distribution_details

        """
        pass

    def test_get_subscriptions(self):
        """Test case for get_subscriptions

        """
        pass

    def test_get_subscriptions1(self):
        """Test case for get_subscriptions1

        """
        pass

    def test_sync_licenses2(self):
        """Test case for sync_licenses2

        """
        pass


if __name__ == '__main__':
    unittest.main()
