"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.system_container_api import SystemContainerApi  # noqa: E501


class TestSystemContainerApi(unittest.TestCase):
    """SystemContainerApi unit test stubs"""

    def setUp(self):
        self.api = SystemContainerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_activate_container(self):
        """Test case for activate_container

        """
        pass

    def test_activate_container_on_remote_host(self):
        """Test case for activate_container_on_remote_host

        """
        pass

    def test_de_activate_container(self):
        """Test case for de_activate_container

        """
        pass

    def test_does_valid_image_exist(self):
        """Test case for does_valid_image_exist

        """
        pass

    def test_get_container_inspect_data(self):
        """Test case for get_container_inspect_data

        """
        pass

    def test_get_container_settings(self):
        """Test case for get_container_settings

        """
        pass

    def test_get_custom_app(self):
        """Test case for get_custom_app

        """
        pass

    def test_test_load_balancer(self):
        """Test case for test_load_balancer

        """
        pass


if __name__ == '__main__':
    unittest.main()
