"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.configuration_multidomain_policy_api import ConfigurationMultidomainPolicyApi  # noqa: E501


class TestConfigurationMultidomainPolicyApi(unittest.TestCase):
    """ConfigurationMultidomainPolicyApi unit test stubs"""

    def setUp(self):
        self.api = ConfigurationMultidomainPolicyApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_internal_policy(self):
        """Test case for add_internal_policy

        """
        pass

    def test_attach_devices(self):
        """Test case for attach_devices

        """
        pass

    def test_detach_devices(self):
        """Test case for detach_devices

        """
        pass

    def test_disconnect_from_mdp(self):
        """Test case for disconnect_from_mdp

        """
        pass

    def test_edit_attached_devices(self):
        """Test case for edit_attached_devices

        """
        pass

    def test_get_mdp_onboarding_status(self):
        """Test case for get_mdp_onboarding_status

        """
        pass

    def test_offboard(self):
        """Test case for offboard

        """
        pass

    def test_onboard_mdp(self):
        """Test case for onboard_mdp

        """
        pass

    def test_retrieve_mdp_attached_devices(self):
        """Test case for retrieve_mdp_attached_devices

        """
        pass

    def test_retrieve_mdp_config_object(self):
        """Test case for retrieve_mdp_config_object

        """
        pass

    def test_retrieve_mdp_policies(self):
        """Test case for retrieve_mdp_policies

        """
        pass

    def test_retrieve_mdp_supported_devices_(self):
        """Test case for retrieve_mdp_supported_devices_

        """
        pass

    def test_update_onboarding_payload(self):
        """Test case for update_onboarding_payload

        """
        pass

    def test_update_policy_status(self):
        """Test case for update_policy_status

        """
        pass


if __name__ == '__main__':
    unittest.main()
