"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.configuration_policy_v_edge_route_definition_builder_api import ConfigurationPolicyVEdgeRouteDefinitionBuilderApi  # noqa: E501


class TestConfigurationPolicyVEdgeRouteDefinitionBuilderApi(unittest.TestCase):
    """ConfigurationPolicyVEdgeRouteDefinitionBuilderApi unit test stubs"""

    def setUp(self):
        self.api = ConfigurationPolicyVEdgeRouteDefinitionBuilderApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_policy_definition24(self):
        """Test case for create_policy_definition24

        """
        pass

    def test_delete_policy_definition24(self):
        """Test case for delete_policy_definition24

        """
        pass

    def test_edit_multiple_policy_definition24(self):
        """Test case for edit_multiple_policy_definition24

        """
        pass

    def test_edit_policy_definition24(self):
        """Test case for edit_policy_definition24

        """
        pass

    def test_get_definitions24(self):
        """Test case for get_definitions24

        """
        pass

    def test_get_policy_definition24(self):
        """Test case for get_policy_definition24

        """
        pass

    def test_preview_policy_definition24(self):
        """Test case for preview_policy_definition24

        """
        pass

    def test_preview_policy_definition_by_id24(self):
        """Test case for preview_policy_definition_by_id24

        """
        pass

    def test_save_policy_definition_in_bulk24(self):
        """Test case for save_policy_definition_in_bulk24

        """
        pass


if __name__ == '__main__':
    unittest.main()
