"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.troubleshooting_tools_device_connectivity_api import TroubleshootingToolsDeviceConnectivityApi  # noqa: E501


class TestTroubleshootingToolsDeviceConnectivityApi(unittest.TestCase):
    """TroubleshootingToolsDeviceConnectivityApi unit test stubs"""

    def setUp(self):
        self.api = TroubleshootingToolsDeviceConnectivityApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_copy_admin_tech_on_device(self):
        """Test case for copy_admin_tech_on_device

        """
        pass

    def test_create_admin_tech(self):
        """Test case for create_admin_tech

        """
        pass

    def test_delete_admin_tech_file(self):
        """Test case for delete_admin_tech_file

        """
        pass

    def test_delete_admin_tech_on_device(self):
        """Test case for delete_admin_tech_on_device

        """
        pass

    def test_download_admin_tech_file(self):
        """Test case for download_admin_tech_file

        """
        pass

    def test_factory_reset(self):
        """Test case for factory_reset

        """
        pass

    def test_get_control_connections(self):
        """Test case for get_control_connections

        """
        pass

    def test_get_device_configuration(self):
        """Test case for get_device_configuration

        """
        pass

    def test_get_in_progress_count(self):
        """Test case for get_in_progress_count

        """
        pass

    def test_invalidate_device(self):
        """Test case for invalidate_device

        """
        pass

    def test_list_admin_techs(self):
        """Test case for list_admin_techs

        """
        pass

    def test_list_admin_techs_on_device(self):
        """Test case for list_admin_techs_on_device

        """
        pass

    def test_nping_device(self):
        """Test case for nping_device

        """
        pass

    def test_ping_device(self):
        """Test case for ping_device

        """
        pass

    def test_process_interface_reset(self):
        """Test case for process_interface_reset

        """
        pass

    def test_process_port_hop_color(self):
        """Test case for process_port_hop_color

        """
        pass

    def test_process_reset_user(self):
        """Test case for process_reset_user

        """
        pass

    def test_service_path(self):
        """Test case for service_path

        """
        pass

    def test_stage_device(self):
        """Test case for stage_device

        """
        pass

    def test_traceroute_device(self):
        """Test case for traceroute_device

        """
        pass

    def test_tunnel_path(self):
        """Test case for tunnel_path

        """
        pass

    def test_upload_admin_tech(self):
        """Test case for upload_admin_tech

        """
        pass


if __name__ == '__main__':
    unittest.main()
