"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.configuration_device_firmware_update_api import ConfigurationDeviceFirmwareUpdateApi  # noqa: E501


class TestConfigurationDeviceFirmwareUpdateApi(unittest.TestCase):
    """ConfigurationDeviceFirmwareUpdateApi unit test stubs"""

    def setUp(self):
        self.api = ConfigurationDeviceFirmwareUpdateApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_activate_firmware_image(self):
        """Test case for activate_firmware_image

        """
        pass

    def test_delete_firmware_image(self):
        """Test case for delete_firmware_image

        """
        pass

    def test_get_devices_fw_upgrade(self):
        """Test case for get_devices_fw_upgrade

        """
        pass

    def test_get_firmware_image_details(self):
        """Test case for get_firmware_image_details

        """
        pass

    def test_get_firmware_images(self):
        """Test case for get_firmware_images

        """
        pass

    def test_install_firmware_image(self):
        """Test case for install_firmware_image

        """
        pass

    def test_process_firmware_image(self):
        """Test case for process_firmware_image

        """
        pass

    def test_remove_firmware_image(self):
        """Test case for remove_firmware_image

        """
        pass


if __name__ == '__main__':
    unittest.main()
