"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.partner_aci_policy_builder_api import PartnerACIPolicyBuilderApi  # noqa: E501


class TestPartnerACIPolicyBuilderApi(unittest.TestCase):
    """PartnerACIPolicyBuilderApi unit test stubs"""

    def setUp(self):
        self.api = PartnerACIPolicyBuilderApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_dscp_mappings(self):
        """Test case for create_dscp_mappings

        """
        pass

    def test_delete_dscp_mappings(self):
        """Test case for delete_dscp_mappings

        """
        pass

    def test_get_aci_definitions(self):
        """Test case for get_aci_definitions

        """
        pass

    def test_get_data_prefix_mappings(self):
        """Test case for get_data_prefix_mappings

        """
        pass

    def test_get_data_prefix_sequences(self):
        """Test case for get_data_prefix_sequences

        """
        pass

    def test_get_dscp_mappings(self):
        """Test case for get_dscp_mappings

        """
        pass

    def test_get_events(self):
        """Test case for get_events

        """
        pass

    def test_set_data_prefix_mappings(self):
        """Test case for set_data_prefix_mappings

        """
        pass


if __name__ == '__main__':
    unittest.main()
