"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import openapi_client
from openapi_client.model.equinix_credentials import EquinixCredentials
from openapi_client.model.megaport_credentials import MegaportCredentials
from openapi_client.model.multi_cloud_edge_billing_account_info import MultiCloudEdgeBillingAccountInfo
from openapi_client.model.multi_cloud_edge_location_info import MultiCloudEdgeLocationInfo
from openapi_client.model.multi_cloud_edge_partner_port import MultiCloudEdgePartnerPort
globals()['EquinixCredentials'] = EquinixCredentials
globals()['MegaportCredentials'] = MegaportCredentials
globals()['MultiCloudEdgeBillingAccountInfo'] = MultiCloudEdgeBillingAccountInfo
globals()['MultiCloudEdgeLocationInfo'] = MultiCloudEdgeLocationInfo
globals()['MultiCloudEdgePartnerPort'] = MultiCloudEdgePartnerPort
from openapi_client.model.multi_cloud_edge_account_info import MultiCloudEdgeAccountInfo


class TestMultiCloudEdgeAccountInfo(unittest.TestCase):
    """MultiCloudEdgeAccountInfo unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testMultiCloudEdgeAccountInfo(self):
        """Test MultiCloudEdgeAccountInfo"""
        # FIXME: construct object with mandatory attributes with example values
        # model = MultiCloudEdgeAccountInfo()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
