"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.configuration_feature_certificate_api import ConfigurationFeatureCertificateApi  # noqa: E501


class TestConfigurationFeatureCertificateApi(unittest.TestCase):
    """ConfigurationFeatureCertificateApi unit test stubs"""

    def setUp(self):
        self.api = ConfigurationFeatureCertificateApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_gen_device_csr(self):
        """Test case for gen_device_csr

        """
        pass

    def test_get_device_certificate(self):
        """Test case for get_device_certificate

        """
        pass

    def test_get_device_csr(self):
        """Test case for get_device_csr

        """
        pass

    def test_get_feature_ca_state(self):
        """Test case for get_feature_ca_state

        """
        pass

    def test_install_feature_certificate(self):
        """Test case for install_feature_certificate

        """
        pass

    def test_revoke_feature_certificate(self):
        """Test case for revoke_feature_certificate

        """
        pass


if __name__ == '__main__':
    unittest.main()
