"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.real_time_monitoring_dpi_api import RealTimeMonitoringDPIApi  # noqa: E501


class TestRealTimeMonitoringDPIApi(unittest.TestCase):
    """RealTimeMonitoringDPIApi unit test stubs"""

    def setUp(self):
        self.api = RealTimeMonitoringDPIApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_dpi_collector_list(self):
        """Test case for create_dpi_collector_list

        """
        pass

    def test_create_dpi_flows_list(self):
        """Test case for create_dpi_flows_list

        """
        pass

    def test_create_dpi_statistics(self):
        """Test case for create_dpi_statistics

        """
        pass

    def test_create_dpi_summary_real_time(self):
        """Test case for create_dpi_summary_real_time

        """
        pass

    def test_get_common_application_list(self):
        """Test case for get_common_application_list

        """
        pass

    def test_get_dpi_device_details_field_json(self):
        """Test case for get_dpi_device_details_field_json

        """
        pass

    def test_get_dpi_device_field_json(self):
        """Test case for get_dpi_device_field_json

        """
        pass

    def test_get_dpi_field_json(self):
        """Test case for get_dpi_field_json

        """
        pass

    def test_get_qosmos_application_list(self):
        """Test case for get_qosmos_application_list

        """
        pass


if __name__ == '__main__':
    unittest.main()
