"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.partner_registration_api import PartnerRegistrationApi  # noqa: E501


class TestPartnerRegistrationApi(unittest.TestCase):
    """PartnerRegistrationApi unit test stubs"""

    def setUp(self):
        self.api = PartnerRegistrationApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_device_mapping(self):
        """Test case for delete_device_mapping

        """
        pass

    def test_delete_partner(self):
        """Test case for delete_partner

        """
        pass

    def test_get_data_change_info(self):
        """Test case for get_data_change_info

        """
        pass

    def test_get_partner(self):
        """Test case for get_partner

        """
        pass

    def test_get_partner_devices(self):
        """Test case for get_partner_devices

        """
        pass

    def test_get_partners(self):
        """Test case for get_partners

        """
        pass

    def test_get_partners_by_partner_type(self):
        """Test case for get_partners_by_partner_type

        """
        pass

    def test_get_vpn_list(self):
        """Test case for get_vpn_list

        """
        pass

    def test_map_devices(self):
        """Test case for map_devices

        """
        pass

    def test_register_partner(self):
        """Test case for register_partner

        """
        pass

    def test_unmap_devices(self):
        """Test case for unmap_devices

        """
        pass

    def test_update_partner(self):
        """Test case for update_partner

        """
        pass


if __name__ == '__main__':
    unittest.main()
