"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.configuration_v_edge_template_policy_api import ConfigurationVEdgeTemplatePolicyApi  # noqa: E501


class TestConfigurationVEdgeTemplatePolicyApi(unittest.TestCase):
    """ConfigurationVEdgeTemplatePolicyApi unit test stubs"""

    def setUp(self):
        self.api = ConfigurationVEdgeTemplatePolicyApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_change_policy_resource_group(self):
        """Test case for change_policy_resource_group

        """
        pass

    def test_create_v_edge_template(self):
        """Test case for create_v_edge_template

        """
        pass

    def test_delete_v_edge_template(self):
        """Test case for delete_v_edge_template

        """
        pass

    def test_edit_v_edge_template(self):
        """Test case for edit_v_edge_template

        """
        pass

    def test_generate_policy_template_list(self):
        """Test case for generate_policy_template_list

        """
        pass

    def test_get_device_list_by_policy(self):
        """Test case for get_device_list_by_policy

        """
        pass

    def test_get_v_edge_policy_device_list(self):
        """Test case for get_v_edge_policy_device_list

        """
        pass

    def test_get_v_edge_template(self):
        """Test case for get_v_edge_template

        """
        pass


if __name__ == '__main__':
    unittest.main()
