"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.real_time_monitoring_system_api import RealTimeMonitoringSystemApi  # noqa: E501


class TestRealTimeMonitoringSystemApi(unittest.TestCase):
    """RealTimeMonitoringSystemApi unit test stubs"""

    def setUp(self):
        self.api = RealTimeMonitoringSystemApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_device_info_list(self):
        """Test case for create_device_info_list

        """
        pass

    def test_create_device_system_process_list(self):
        """Test case for create_device_system_process_list

        """
        pass

    def test_create_device_system_setting(self):
        """Test case for create_device_system_setting

        """
        pass

    def test_create_device_system_setting_native_info(self):
        """Test case for create_device_system_setting_native_info

        """
        pass

    def test_create_device_system_stats_list(self):
        """Test case for create_device_system_stats_list

        """
        pass

    def test_create_device_system_status(self):
        """Test case for create_device_system_status

        """
        pass

    def test_create_device_system_status_list(self):
        """Test case for create_device_system_status_list

        """
        pass

    def test_create_synced_device_system_status_list(self):
        """Test case for create_synced_device_system_status_list

        """
        pass


if __name__ == '__main__':
    unittest.main()
